==> bambootracker_0.4.6.orig.tar.gz: BambooTracker-0.4.6/EFFECTLIST.md <==
## Effect list
| Effect | FM                                                                                      | SSG                                                                | Rhythm                            | ADPCM                   | ADPCM Drumkit                                                                            |
| ------ | --------------------------------------------------------------------------------------- | ------------------------------------------------------------------ | --------------------------------- | ----------------------- | ---------------------------------------------------------------------------------------- |
| 00xy   | Arpeggio (x[0-F]: 2nd note, y[0-F]: 3rd note)                                           | Arpeggio                                                           | -                                 | Arpeggio                | -                                                                                        |
| 01xx   | Portamento up (xx[00-FF]: depth)                                                        | Portamento up                                                      | -                                 | Portamento up           | -                                                                                        |
| 02xx   | Portamento down (xx[00-FF]: depth)                                                      | Portamento down                                                    | -                                 | Portamento down         | -                                                                                        |
| 03xx   | Tone portamento (xx[00-FF]: depth)                                                      | Tone portamento                                                    | -                                 | Tone portamento         | -                                                                                        |
| 04xy   | Vibrato (x[0-F]: period, y[0-F]: depth)                                                 | Vibrato                                                            | -                                 | Vibrato                 | -                                                                                        |
| 07xy   | Tremolo (x[0-F]: period, y[0-F]: depth)                                                 | Tremolo                                                            | -                                 | Tremolo                 | Tremolo                                                                                  |
| 08xx   | Pan (xx: 00=No sound, 01=Right, 02=Left, 03=Center)                                     | -                                                                  | Pan                               | Pan                     | Pan                                                                                      |
| 0A0x   | Volume slide down (x[0-F]: depth)                                                       | Volume slide down                                                  | -                                 | Volume slide down       | Volume slide down                                                                        |
| 0Ax0   | Volume slide up (x[0-F]: depth)                                                         | Volume slide up                                                    | -                                 | Volume slide up         | Volume slide up                                                                          |
| 0Bxx   | Position jump (xx: order)                                                               | Position jump                                                      | Position jump                     | Position jump           | Position jump                                                                            |
| 0Cxx   | Song end (xx: any number)                                                               | Song end                                                           | Song end                          | Song end                | Song end                                                                                 |
| 0Dxx   | Pattern break (xx: start step on the next order)                                        | Pattern break                                                      | Pattern break                     | Pattern break           | Pattern break                                                                            |
| 0Fxx   | Speed/Tempo change (xx[00-1F]: speed, [20-FF]: tempo)                                   | Speed/Tempo change                                                 | Speed/Tempo change                | Speed/Tempo change      | Speed/Tempo change                                                                       |
| 0Gxx   | Note delay (xx[00-FF]: count)                                                           | Note delay                                                         | Note delay                        | Note delay              | Note delay                                                                               |
| 0Hxy   | -                                                                                       | Auto envelope (x[0-F]: shift amount (x-8), y[0-F]: shape)          | -                                 | -                       | -                                                                                        |
| 0Ixx   | -                                                                                       | Hardware envelope period 1 (xx[00-FF]: high byte)                  | -                                 | -                       | -                                                                                        |
| 0Jxx   | -                                                                                       | Hardware envelope period 2 (xx[00-FF]: low byte)                   | -                                 | -                       | -                                                                                        |
| 0Oxx   | Groove (xx[00-FF]: number)                                                              | Groove                                                             | Groove                            | Groove                  | Groove                                                                                   |
| 0Pxx   | Detune (xx[00-FF]: pitch (xx-80))                                                       | Detune                                                             | -                                 | Detune                  | -                                                                                        |
| 0Qxy   | Note slide up (x[0-F]: count, y[0-F]: seminote)                                         | Note slide up                                                      | -                                 | Note slide up           | -                                                                                        |
| 0Rxy   | Note slide down (x[0-F]: count, y[0-F]: seminote)                                       | Note slide down                                                    | -                                 | Note slide down         | -                                                                                        |
| 0Sxx   | Note cut (xx[01-FF]: count)                                                             | Note cut                                                           | Note cut                          | Note cut                | Note cut                                                                                 |
| 0Txy   | Transpose delay (x[1-7]: upwards count, [9-F]: downwards count (x-8), y[0-F]: seminote) | Transpose delay                                                    | -                                 | Transpose delay         | Key change delay (x[1-7]: upwards count, [9-F]: downwards count (x-8), y[0-F]: seminote) |
| 0Vxx   | -                                                                                       | Tone/Noise mix (xx: 00=No sound, 01=Tone, 02=Noise, 03=Tone&Noise) | Master volume (xx[00-3F]: volume) | -                       | -                                                                                        |
| 0Wxx   | -                                                                                       | -                                                                  | Noise pitch (xx[00-1F]: pitch)    | -                       | -                                                                                        |
| 0Xxx   | Register address bank 0 (xx[00-B6]: address)                                            | Register address bank 0                                            | Registe address bank 0            | Register address bank 0 | Register address bank 0                                                                  |
| 0Yxx   | Register address bank 1 (xx[00-B6]: address)                                            | Register address bank 1                                            | Registe address bank 1            | Register address bank 1 | Register address bank 1                                                                  |
| 0Zxx   | Regisetr value set (xx[00-FF]: value)                                                   | Register value set                                                 | Register value set                | Register value set      | Register value set                                                                       |
| Axyy   | AR control (x[1-4]: operator, y[00-1F]: attack rate)                                    | -                                                                  | -                                 | -                       | -                                                                                        |
| B0xx   | Brightness (xx[01-FF]: relative value (xx-80))                                          | -                                                                  | -                                 | -                       | -                                                                                        |
| Dxyy   | DR control (x[1-4]: operator, y[00-1F]: decay rate)                                     | -                                                                  | -                                 | -                       | -                                                                                        |
| FBxx   | FB control (xx[00-07]: feedback value)                                                  | -                                                                  | -                                 | -                       | -                                                                                        |
| FPxx   | Fine detune (xx[00-FF]: pitch (xx-80))                                                  | Fine detune                                                        | -                                 | Fine detune             | -                                                                                        |
| Mxyy   | Volume delay (x[1-F]: count, yy[00-FF]: volume)                                         | Volume delay                                                       | Volume delay                      | Volume delay            | Volume delay                                                                             |
| MLxy   | ML control (x[1-4]: operator, y[0-F]: multiple)                                         | -                                                                  | -                                 | -                       | -                                                                                        |
| RRxy   | RR control (x[1-4]: operator, y[0-F]: release rate)                                     | -                                                                  | -                                 | -                       | -                                                                                        |
| Txyy   | TL control (x[1-4]: operator, yy[00-7F]: total level)                                   | -                                                                  | -                                 | -                       | -                                                                                        |

==> bambootracker_0.5.1.orig.tar.gz: BambooTracker-0.5.1/EFFECTLIST.md <==
# Effect List

| Effect | FM                                                                                      | SSG                                                                | Rhythm                            | ADPCM                   | ADPCM Drumkit                                                                            |
| ------ | --------------------------------------------------------------------------------------- | ------------------------------------------------------------------ | --------------------------------- | ----------------------- | ---------------------------------------------------------------------------------------- |
| 00xy   | Arpeggio (x[0-F]: 2nd note, y[0-F]: 3rd note)                                           | Arpeggio                                                           | -                                 | Arpeggio                | -                                                                                        |
| 01xx   | Portamento up (xx[00-FF]: depth)                                                        | Portamento up                                                      | -                                 | Portamento up           | -                                                                                        |
| 02xx   | Portamento down (xx[00-FF]: depth)                                                      | Portamento down                                                    | -                                 | Portamento down         | -                                                                                        |
| 03xx   | Tone portamento (xx[00-FF]: depth)                                                      | Tone portamento                                                    | -                                 | Tone portamento         | -                                                                                        |
| 04xy   | Vibrato (x[0-F]: period, y[0-F]: depth)                                                 | Vibrato                                                            | -                                 | Vibrato                 | -                                                                                        |
| 07xy   | Tremolo (x[0-F]: period, y[0-F]: depth)                                                 | Tremolo                                                            | -                                 | Tremolo                 | Tremolo                                                                                  |
| 08xx   | Pan (xx: 00=No sound, 01=Right, 02=Left, 03=Center)                                     | -                                                                  | Pan                               | Pan                     | Pan                                                                                      |
| 0A0x   | Volume slide down (x[0-F]: depth)                                                       | Volume slide down                                                  | -                                 | Volume slide down       | Volume slide down                                                                        |
| 0Ax0   | Volume slide up (x[0-F]: depth)                                                         | Volume slide up                                                    | -                                 | Volume slide up         | Volume slide up                                                                          |
| 0Bxx   | Position jump (xx: order)                                                               | Position jump                                                      | Position jump                     | Position jump           | Position jump                                                                            |
| 0Cxx   | Song end (xx: any number)                                                               | Song end                                                           | Song end                          | Song end                | Song end                                                                                 |
| 0Dxx   | Pattern break (xx: start step on the next order)                                        | Pattern break                                                      | Pattern break                     | Pattern break           | Pattern break                                                                            |
| 0Fxx   | Speed/Tempo change (xx[00-1F]: speed, [20-FF]: tempo)                                   | Speed/Tempo change                                                 | Speed/Tempo change                | Speed/Tempo change      | Speed/Tempo change                                                                       |
| 0Gxx   | Note delay (xx[00-FF]: count)                                                           | Note delay                                                         | Note delay                        | Note delay              | Note delay                                                                               |
| 0Hxy   | -                                                                                       | Auto envelope (x[0-F]: shift amount (x-8), y[0-F]: shape)          | -                                 | -                       | -                                                                                        |
| 0Ixx   | -                                                                                       | Hardware envelope period 1 (xx[00-FF]: high byte)                  | -                                 | -                       | -                                                                                        |
| 0Jxx   | -                                                                                       | Hardware envelope period 2 (xx[00-FF]: low byte)                   | -                                 | -                       | -                                                                                        |
| 0Kxy   | Retrigger (x[0-7]: volume up, [8-F]: volume down (x-8), y[1-F]: tick)                   | Retrigger                                                          | Retrigger                         | Retrigger               | Retrigger                                                                                |
| 0Oxx   | Groove (xx[00-FF]: number)                                                              | Groove                                                             | Groove                            | Groove                  | Groove                                                                                   |
| 0Pxx   | Detune (xx[00-FF]: pitch (xx-80))                                                       | Detune                                                             | -                                 | Detune                  | -                                                                                        |
| 0Qxy   | Note slide up (x[0-F]: count, y[0-F]: seminote)                                         | Note slide up                                                      | -                                 | Note slide up           | -                                                                                        |
| 0Rxy   | Note slide down (x[0-F]: count, y[0-F]: seminote)                                       | Note slide down                                                    | -                                 | Note slide down         | -                                                                                        |
| 0Sxx   | Note cut (xx[00-FF]: count)                                                             | Note cut                                                           | Note cut                          | Note cut                | Note cut                                                                                 |
| 0Txy   | Transpose delay (x[0-7]: upwards count, [8-F]: downwards count (x-8), y[0-F]: seminote) | Transpose delay                                                    | -                                 | Transpose delay         | Key change delay (x[0-7]: upwards count, [8-F]: downwards count (x-8), y[0-F]: seminote) |
| 0Vxx   | -                                                                                       | Tone/Noise mix (xx: 00=No sound, 01=Tone, 02=Noise, 03=Tone&Noise) | Master volume (xx[00-3F]: volume) | -                       | -                                                                                        |
| 0Wxx   | -                                                                                       | -                                                                  | Noise pitch (xx[00-1F]: pitch)    | -                       | -                                                                                        |
| 0Xxx   | Register address bank 0 (xx[00-B6]: address)                                            | Register address bank 0                                            | Registe address bank 0            | Register address bank 0 | Register address bank 0                                                                  |
| 0Yxx   | Register address bank 1 (xx[00-B6]: address)                                            | Register address bank 1                                            | Registe address bank 1            | Register address bank 1 | Register address bank 1                                                                  |
| 0Zxx   | Regisetr value set (xx[00-FF]: value)                                                   | Register value set                                                 | Register value set                | Register value set      | Register value set                                                                       |
| Axyy   | AR control (x[1-4]: operator, y[00-1F]: attack rate)                                    | -                                                                  | -                                 | -                       | -                                                                                        |
| B0xx   | Brightness (xx[01-FF]: relative value (xx-80))                                          | -                                                                  | -                                 | -                       | -                                                                                        |
| Dxyy   | DR control (x[1-4]: operator, y[00-1F]: decay rate)                                     | -                                                                  | -                                 | -                       | -                                                                                        |
| EAxy   | Extended volume slide (x[0-F]: up, y[0-F]: down)                                        | Extended volume slide                                              | -                                 | Extended volume slide   | Extended volume slide                                                                    |
| ESxx   | Envelope reset (xx[00-FF]: count)                                                       | -                                                                  | -                                 | -                       | -                                                                                        |
| FBxx   | FB control (xx[00-07]: feedback value)                                                  | -                                                                  | -                                 | -                       | -                                                                                        |
| FPxx   | Fine detune (xx[00-FF]: pitch (xx-80))                                                  | Fine detune                                                        | -                                 | Fine detune             | -                                                                                        |
| Mxyy   | Volume delay (x[0-F]: count, yy[00-FF]: volume)                                         | Volume delay                                                       | Volume delay                      | Volume delay            | Volume delay                                                                             |
| MLxy   | ML control (x[1-4]: operator, y[0-F]: multiple)                                         | -                                                                  | -                                 | -                       | -                                                                                        |
| RRxy   | RR control (x[1-4]: operator, y[0-F]: release rate)                                     | -                                                                  | -                                 | -                       | -                                                                                        |
| Txyy   | TL control (x[1-4]: operator, yy[00-7F]: total level)                                   | -                                                                  | -                                 | -                       | -                                                                                        |
